@@ -6,7 +6,7 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 LOGGER_FORMAT = "[{levelname}: {filename}:{lineno}]: {message}"
 
-__version__ = "1.1.1"
+__version__ = "1.2.1"
 
 
 def start_logging(
@@ -26,3 +26,8 @@ def start_logging(
     logger.debug("Logging enabled for %s", __name__)
 
     return handler
+
+
+from ._ext import setup  # noqa: E402
+
+__all__ = ["setup"]
